==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/LabelClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LabelClickEventArgsDescription } from "./LabelClickEventArgsDescription";
/**
 * @hidden
 */
export let LabelClickEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class LabelClickEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (LabelClickEventArgsDescriptionMetadata.a == null) {
                LabelClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LabelClickEventArgsDescriptionMetadata.c(LabelClickEventArgsDescriptionMetadata.a);
            }
            if (a.k(LabelClickEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(LabelClickEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("AllowSliceClick", "Boolean");
        }
        static d(a) {
            LabelClickEventArgsDescriptionMetadata.b(a);
            a.ad("LabelClickEventArgs", () => new LabelClickEventArgsDescription());
            a.ac("LabelClickEventArgs", LabelClickEventArgsDescriptionMetadata.a);
        }
    }
    LabelClickEventArgsDescriptionMetadata.$t = markType(LabelClickEventArgsDescriptionMetadata, 'LabelClickEventArgsDescriptionMetadata');
    LabelClickEventArgsDescriptionMetadata.a = null;
    return LabelClickEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/LabelClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LabelClickEventArgsDescription } from "./LabelClickEventArgsDescription";
/**
 * @hidden
 */
export let LabelClickEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class LabelClickEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (LabelClickEventArgsDescriptionMetadata.a == null) {
                LabelClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LabelClickEventArgsDescriptionMetadata.c(LabelClickEventArgsDescriptionMetadata.a);
            }
            if (a.k(LabelClickEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(LabelClickEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("AllowSliceClick", "Boolean");
        }
        static d(a) {
            LabelClickEventArgsDescriptionMetadata.b(a);
            a.ae("LabelClickEventArgs", () => new LabelClickEventArgsDescription());
            a.ad("LabelClickEventArgs", LabelClickEventArgsDescriptionMetadata.a);
        }
    }
    LabelClickEventArgsDescriptionMetadata.$t = markType(LabelClickEventArgsDescriptionMetadata, 'LabelClickEventArgsDescriptionMetadata');
    LabelClickEventArgsDescriptionMetadata.a = null;
    return LabelClickEventArgsDescriptionMetadata;
})();
